## mongodb-dataset

![Build](https://github.com/TadpoleTutoring/mongodb-dataset/workflows/Python%20testing%20and%20linting/badge.svg)
[![codecov](https://codecov.io/gh/TadpoleTutoring/mongodb-dataset/branch/master/graph/badge.svg?token=kh26hWszR0)](https://codecov.io/gh/TadpoleTutoring/mongodb-dataset)


Pythonic wrapper around pymongo that can act as a drop-in replacement for dataset 
